package com.caimei365.user.components;

import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.LoginMapper;
import com.caimei365.user.mapper.OperationMapper;
import com.caimei365.user.model.po.OperationPo;
import com.caimei365.user.model.vo.UserLoginVo;
import com.caimei365.user.utils.ValidateUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/26
 */
@Slf4j
@Service
public class CommonService {
    @Resource
    private RedisService redisService;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private LoginMapper loginMapper;
    @Resource
    private OperationMapper operationMapper;
    @Value("${spring.cloud.config.profile}")
    private String profile;
    /**
     * 校验邮箱
     * @param email 邮箱
     * @return errorMsg
     */
    public String emailValidate(String email) {
        if (!ValidateUtil.validateEmail(email)) {
            return  "邮箱格式不正确";
        }
        Integer userIdByEmail = baseMapper.getUserIdByEmail(email);
        if (null != userIdByEmail && userIdByEmail > 0 ) {
            return "该邮箱已被使用";
        }
        return null;
    }
    /**
     * 校验手机号与验证码
     * @param mobile 手机号
     * @param smsCode 验证码
     * @return errorMsg
     */
    public String mobileAndCodeValidate(String mobile, String smsCode) {
        String result = ValidateUtil.validateMobile(mobile);
        if (result != null) {return result;}
        if (StringUtils.isNotBlank(smsCode)){
            String redisSmsCode = (String) redisService.get("code:" + mobile);
            // 开发 和 测试环境 固定短信验证码 666666
            if ("dev".equals(profile) || "beta".equals(profile)){
                redisSmsCode = (null != redisSmsCode && !"null".equals(redisSmsCode) ? redisSmsCode : "666666");
            }
            log.info("手机验证码校验" + smsCode.equals(redisSmsCode));
            if (!smsCode.equals(redisSmsCode)) {
                return "手机验证码错误";
            }
        }
        boolean flag = false;
        // 查找用户表是否存在
        Integer dbUserId = baseMapper.getUserIdByMobile(mobile);
        if (null != dbUserId && dbUserId > 0) {
            UserLoginVo user = loginMapper.getLoginUserByUserId(dbUserId);
            String showName = ValidateUtil.nameConversion(user.getUserName());
            if (2 == user.getUserIdentity() || 4 == user.getUserIdentity()) {
                return "该手机号已绑定机构(" + showName + ")联系人，请重新填写手机号";
            } else if (3 == user.getUserIdentity()) {
                return "该手机号已绑定供应商(" + showName + ")联系人，请重新填写手机号";
            }
            flag = true;
        }
        // 查找运营人员表是否存在
        Integer dbOperationId = baseMapper.getOperationIdByMobile(mobile);
        if (null != dbOperationId && dbOperationId > 0) {
            UserLoginVo operation = loginMapper.getOperationUserByOperationId(dbOperationId);
            String showName = ValidateUtil.nameConversion(operation.getUserName());
            if (2 == operation.getUserIdentity() || 4 == operation.getUserIdentity()) {
                return "该手机号已绑定机构(" + showName + ")运营人员，请重新填写手机号";
            } else if (3 == operation.getUserIdentity()) {
                return "该手机号已绑定供应商(" + showName + ")运营人员，请重新填写手机号";
            }
            flag = true;
        }
        if (flag) {
            return "该手机号已被使用";
        }
        return null;
    }

    /**
     * 查询使用该手机号的运营人员或用户
     */
    public String operationBindCheck(String mobile, String smsCode) {
        // 手机号验证
        String result = mobileAndCodeValidate(mobile, smsCode);
        if ("手机验证码错误".equals(result)) {
            return result;
        }
        if (result != null) {
            // 查询使用该手机号的运营人员或用户
            UserLoginVo dbUser = loginMapper.getLoginUserByMobile(mobile);
            boolean offlineClub = false;
            boolean offlineShop = false;
            if (null != dbUser) {
                if (mobile.equals(dbUser.getBindMobile())) {
                    // 判断运营人员手机号的唯一性
                    Integer dbOperationId = baseMapper.getOperationIdByMobile(mobile);
                    if (dbOperationId != null && dbOperationId > 0) {
                        return "该手机号已注册并绑定微信！";
                    }
                    // 联系人作为运营人员，放行
                    return null;
                }
                // 已下线机构
                offlineClub = null != dbUser.getClubStatus() && 91 == dbUser.getClubStatus();
                // 已下线供应商
                offlineShop = null != dbUser.getShopStatus() && 91 == dbUser.getShopStatus();
            }
            if (offlineClub || offlineShop) {
                // 解绑已下线的运营人员
                unbindOperation(dbUser.getOperationId());
                return null;
            } else {
                return result;
            }
        }
        return null;
    }

    /**
     * 解绑运营人员
     *
     * @param operationId 运营人员Id
     */
    public int unbindOperation(Integer operationId) {
        OperationPo operation = new OperationPo();
        operation.setId(operationId);
        operation.setUnionId("");
        operation.setOpenId("");
        operation.setNickName("");
        operation.setBindTime(null);
        operation.setUpdateTime(new Date());
        operation.setStatus(1);
        operation.setDelFlag(1);
        // 解绑运营人员
        return operationMapper.updateOperationByUnbind(operation);
    }
}
